<?php

declare(strict_types=1);

namespace Apexl\Io\Admin;

use Apexl\Io\Admin\Enums\Permissions\Admin;
use Apexl\Io\Module;
use Apexl\Io\User\Interfaces\ProvidesPermissionsInterface;
use Apexl\Io\User\Services\Permissions;

readonly class AdminModule extends Module implements ProvidesPermissionsInterface
{
    public function permissions(Permissions $permissions): void
    {
        $permissions->registerPermission(Admin::ADMINISTER, 'Access Administration', 'Admin');
        $permissions->registerPermission(Admin::CONFIGURE, 'Manage Configuration', 'Admin');
    }
}
