<?php

declare(strict_types=1);

namespace Apexl\Io\Admin\Enums\Permissions;

use Apexl\Io\User\Interfaces\PermissionInterface;
use Apexl\Io\User\Traits\IsPermissionTrait;

enum Admin implements PermissionInterface, \JsonSerializable
{
    use IsPermissionTrait;

    case CONFIGURE;
    case ADMINISTER;
}

